@@ -51,12 +51,12 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KCMNetworkmanagement, "kcm_networkmanagement.json")
 
-KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
+KCMNetworkmanagement::KCMNetworkmanagement(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : KCModule(parent, metaData)
     , m_handler(new Handler(this))
     , m_ui(new Ui::KCMForm)
 {
-    auto mainWidget = new QWidget(this);
+    auto mainWidget = new QWidget(widget());
     m_ui->setupUi(mainWidget);
 
     KLocalizedContext *l10nContext = new KLocalizedContext(m_ui->connectionView->engine());
@@ -102,20 +102,15 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
     m_ui->connectionView->rootContext()->setContextProperty("textColor", mainWidget->palette().color(QPalette::Active, QPalette::Text));
     m_ui->connectionView->rootContext()->setContextProperty("connectionModified", false);
     m_ui->connectionView->rootContext()->setContextProperty("useApMode", useApMode);
+    m_ui->connectionView->rootContext()->setContextProperty("kcm", this);
     m_ui->connectionView->setClearColor(Qt::transparent);
     m_ui->connectionView->setResizeMode(QQuickWidget::SizeRootObjectToView);
     m_ui->connectionView->setSource(
         QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kcm_networkmanagement/qml/main.qml"))));
 
-    QObject *rootItem = m_ui->connectionView->rootObject();
-    connect(rootItem, SIGNAL(selectedConnectionChanged(QString)), this, SLOT(onSelectedConnectionChanged(QString)));
-    connect(rootItem, SIGNAL(requestCreateConnection(int, QString, QString, bool)), this, SLOT(onRequestCreateConnection(int, QString, QString, bool)));
-    connect(rootItem, SIGNAL(requestExportConnection(QString)), this, SLOT(onRequestExportConnection(QString)));
-    connect(rootItem, SIGNAL(requestToChangeConnection(QString, QString)), this, SLOT(onRequestToChangeConnection(QString, QString)));
+    auto l = new QVBoxLayout(widget());
 
-    auto l = new QVBoxLayout(this);
-
-    m_errorWidget = new KMessageWidget(this);
+    m_errorWidget = new KMessageWidget(widget());
     m_errorWidget->setVisible(false);
     m_errorWidget->setMessageType(KMessageWidget::Error);
     l->addWidget(m_errorWidget);
@@ -193,6 +188,7 @@ KCMNetworkmanagement::KCMNetworkmanagement(QWidget *parent, const QVariantList &
     if (selectedConnection && selectedConnection->isValid()) {
         const NetworkManager::ConnectionSettings::Ptr settings = selectedConnection->settings();
         if (UiUtils::isConnectionTypeSupported(settings->connectionType())) {
+            QObject *rootItem = m_ui->connectionView->rootObject();
             QMetaObject::invokeMethod(rootItem, "selectConnection", Q_ARG(QVariant, settings->id()), Q_ARG(QVariant, selectedConnection->path()));
         }
     } else {
@@ -292,7 +288,7 @@ void KCMNetworkmanagement::onRequestCreateConnection(int connectionType, const Q
         }
 
     } else if (type == NetworkManager::ConnectionSettings::Gsm) { // launch the mobile broadband wizard, both gsm/cdma
-        QPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, this);
+        QPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, widget());
         wizard->setAttribute(Qt::WA_DeleteOnClose);
         connect(wizard.data(), &MobileConnectionWizard::accepted, [wizard, this]() {
             if (wizard->getError() == MobileProviders::Success) {
@@ -427,7 +423,7 @@ void KCMNetworkmanagement::onRequestExportConnection(const QString &connectionPa
         const QString url =
             QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation) + QDir::separator() + vpnPlugin->suggestedFileName(connSettings);
         const QString filename =
-            QFileDialog::getSaveFileName(this, i18n("Export VPN Connection"), url, vpnPlugin->supportedFileExtensions().join(QLatin1Char(' ')));
+            QFileDialog::getSaveFileName(widget(), i18n("Export VPN Connection"), url, vpnPlugin->supportedFileExtensions().join(QLatin1Char(' ')));
         if (!filename.isEmpty()) {
             if (auto result = vpnPlugin->exportConnectionSettings(connSettings, filename)) {
                 // TODO display success
@@ -446,23 +442,14 @@ void KCMNetworkmanagement::onRequestToChangeConnection(const QString &connection
     NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(m_currentConnectionPath);
 
     if (connection) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
-        if (KMessageBox::questionTwoActions(this,
-#else
-        if (KMessageBox::questionYesNo(this,
-
-#endif
+        if (KMessageBox::questionTwoActions(widget(),
                                             i18n("Do you want to save changes made to the connection '%1'?", connection->name()),
                                             i18nc("@title:window", "Save Changes"),
                                             KStandardGuiItem::save(),
                                             KStandardGuiItem::discard(),
                                             QString(),
                                             KMessageBox::Notify)
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            == KMessageBox::Yes) {
-#endif
             save();
         }
     }
@@ -503,7 +490,7 @@ void KCMNetworkmanagement::addConnection(const NetworkManager::ConnectionSetting
 void KCMNetworkmanagement::kcmChanged(bool kcmChanged)
 {
     m_ui->connectionView->rootContext()->setContextProperty("connectionModified", kcmChanged);
-    Q_EMIT changed(kcmChanged);
+    setNeedsSave(kcmChanged);
 }
 
 void KCMNetworkmanagement::loadConnectionSettings(const NetworkManager::ConnectionSettings::Ptr &connectionSettings)
@@ -541,7 +528,7 @@ KCMNetworkmanagement::ImportResult KCMNetworkmanagement::ImportResult::fail(cons
 KCMNetworkmanagement::ImportResult KCMNetworkmanagement::importVpn()
 {
     // get the list of supported extensions
-    const QVector<KPluginMetaData> services = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"));
+    const QList<KPluginMetaData> services = KPluginMetaData::findPlugins(QStringLiteral("plasma/network/vpn"));
     QStringList extensions;
     for (const KPluginMetaData &service : services) {
         const auto result = KPluginFactory::instantiatePlugin<VpnUiPlugin>(service);
@@ -551,8 +538,10 @@ KCMNetworkmanagement::ImportResult KCMNetworkmanagement::importVpn()
         }
     }
 
-    const QString &filename =
-        QFileDialog::getOpenFileName(this, i18n("Import VPN Connection"), QDir::homePath(), i18n("VPN connections (%1)", extensions.join(QLatin1Char(' '))));
+    const QString &filename = QFileDialog::getOpenFileName(widget(),
+                                                           i18n("Import VPN Connection"),
+                                                           QDir::homePath(),
+                                                           i18n("VPN connections (%1)", extensions.join(QLatin1Char(' '))));
 
     if (filename.isEmpty()) {
         return ImportResult::fail(i18n("No file was provided"));
@@ -629,7 +618,9 @@ void KCMNetworkmanagement::resetSelection()
         delete m_tabWidget;
         m_tabWidget = nullptr;
     }
-    Q_EMIT changed(false);
+    setNeedsSave(false);
 }
 
 #include "kcm.moc"
+
+#include "moc_kcm.cpp"
